@@ -352,6 +352,43 @@ def wireguard_example():
         pprint(reply)
 
 
+def vpp_stats_example():
+    """Example using transient VPPStatsQuery based stats API."""
+
+    with ExtendedVPPAPIClient() as client:
+        # Collect stats for specific interfaces
+        query = models.VPPStatsQuery(
+            interface_names=["wg0", "vpp-wan"],
+            include_error_counters=True,
+            debug=True,
+        )
+        print("Collecting interface-specific VPP statistics for wg0 and vpp-wan...")
+        reply = client.get_vpp_stats(query)
+        if reply.success:
+            for if_name in ["wg0", "vpp-wan"]:
+                counters = reply.summarize_interface(if_name)
+                if counters:
+                    print(f"{if_name}: {counters}")
+        else:
+            print(f"Failed to collect interface stats: {reply.error}")
+
+        # General stats collection with patterns
+        general_query = models.VPPStatsQuery(
+            patterns=["/if/rx", "/if/tx", "/if/drops"],
+            include_error_counters=False,
+            debug=True,
+        )
+        print("\nCollecting general VPP statistics...")
+        general_reply = client.get_vpp_stats(general_query)
+        if general_reply.success:
+            print(f"Collected {len(general_reply.entries)} entries")
+            sample = general_reply.entries[:5]
+            for e in sample:
+                print(f"  {e.name} ({e.type})")
+        else:
+            print(f"Failed to collect general stats: {general_reply.error}")
+
+
 def frr_example():
     """Example of how to configure FRR running inside another docker.
 
@@ -924,4 +961,7 @@ if __name__ == "__main__":
     # from_docker_to_host_example()
     # linux_route_example()
     # wireguard_state_update_detection_example()
-    dhcp_example()
+    #dhcp_example()
+    vpp_stats_example() 
+
+    
