@@ -1368,3 +1368,260 @@ class LCPPairDetail:  # lcp_itf_pair_details
             host_if_type=int(obj.host_if_type),  # vl_api_lcp_itf_host_type_t
             netns=obj.netns,
         )
+
+
+# VPP Stats related models
+
+class VPPStatsType(Enum):
+    """Types of VPP statistics that can be collected"""
+    SCALAR = "scalar"
+    COUNTER_VECTOR_SIMPLE = "counter_vector_simple"
+    COUNTER_VECTOR_COMBINED = "counter_vector_combined"
+    ERROR_INDEX = "error_index"
+    NAME_VECTOR = "name_vector"
+
+
+@dataclass_json
+@dataclass
+
+@dataclass_json
+@dataclass
+class VPPStatsQuery:
+    """Transient (non-persisted) VPP statistics query.
+
+    This model supersedes VPPStatsConfigurationItem for one-off stats retrieval via
+    ExtendedVPPAPIClient.get_vpp_stats(). It is NOT a ConfigurationItem and is never
+    stored server-side.
+
+    Parameters:
+      patterns: Optional explicit list of stat name prefixes/regex (as accepted by VPP stats API) to request.
+      interface_names: When provided, interface specific paths will be auto-generated (both modern
+                       '/interfaces/<if>/(rx|tx|drops|error|punt|ip4|ip6)?' and legacy '/if/(rx|tx|drops)' forms
+                       for compatibility, unless disable_legacy_interface_paths is True).
+      stats_socket_path: Path to the VPP stats Unix socket.
+      include_error_counters: Include '/err/' error counters (per thread) automatically.
+      disable_legacy_interface_paths: Do not include legacy '/if/' paths when True.
+    """
+    patterns: List[str] = field(default_factory=list)
+    interface_names: List[str] = field(default_factory=list)
+    stats_socket_path: str = "/run/vpp/stats.sock"
+    include_error_counters: bool = True
+    disable_legacy_interface_paths: bool = False
+    debug: bool = False
+   
+
+@dataclass_json
+@dataclass
+class VPPCounterValue:
+    """Represents a single counter value with metadata"""
+    packets: int = 0
+    bytes: int = 0
+    
+
+@dataclass_json
+@dataclass
+class VPPStatsEntry:
+    """Single statistics entry from VPP"""
+    name: str = ""
+    """Name/path of the statistic (e.g., '/if/rx', '/err/ip4-input')"""
+    type: VPPStatsType = VPPStatsType.SCALAR
+    """Type of the statistic"""
+    
+    # For scalar values
+    scalar_value: float = 0.0
+    
+    # For simple counter vectors (per-thread, per-interface arrays)
+    simple_counter_vec: List[List[int]] = field(default_factory=lambda: [])
+    
+    # For combined counter vectors (packets + bytes per-thread, per-interface)
+    combined_counter_vec: List[List[VPPCounterValue]] = field(default_factory=lambda: [])
+    
+    # For error counters (per-thread arrays)
+    error_vector: List[int] = field(default_factory=lambda: [])
+    
+    # For name vectors
+    name_vector: List[str] = field(default_factory=lambda: [])
+
+
+@dataclass_json
+@dataclass
+class VPPStatsReply:
+    """Reply containing collected VPP statistics"""
+    success: bool = True
+    error: str = ""
+    timestamp: str = ""
+    """ISO timestamp when statistics were collected"""
+    entries: List[VPPStatsEntry] = field(default_factory=lambda: [])
+    """List of collected statistics entries"""
+    debug_info: List[str] = field(default_factory=list)
+    """Optional debug lines with raw data shape / conversion info when debug enabled"""
+    
+    def get_interface_counters(self, interface_index: int = 0, thread_index: int = 0) -> Dict[str, Any]:
+        """Helper method to extract interface counters for a specific interface and thread"""
+        counters = {}
+        for entry in self.entries:
+            if entry.name.startswith('/if/'):
+                counter_type = entry.name.split('/')[-1]  # rx, tx, drops, etc.
+                if entry.type == VPPStatsType.COUNTER_VECTOR_SIMPLE:
+                    if (thread_index < len(entry.simple_counter_vec) and 
+                        interface_index < len(entry.simple_counter_vec[thread_index])):
+                        counters[counter_type] = entry.simple_counter_vec[thread_index][interface_index]
+                elif entry.type == VPPStatsType.COUNTER_VECTOR_COMBINED:
+                    if (thread_index < len(entry.combined_counter_vec) and 
+                        interface_index < len(entry.combined_counter_vec[thread_index])):
+                        counter_val = entry.combined_counter_vec[thread_index][interface_index]
+                        counters[counter_type] = {
+                            'packets': counter_val.packets,
+                            'bytes': counter_val.bytes
+                        }
+        return counters
+        
+    def get_interface_counters_by_name(self, interface_name: str) -> Dict[str, Any]:
+        """Helper method to extract interface counters for a specific interface by name (e.g., 'wg0')"""
+        counters = {}
+        
+        # Look for interface-specific entries like /interfaces/wg0/rx, /interfaces/wg0/tx, etc.
+        base_pattern = f"/interfaces/{interface_name}/"
+        
+        for entry in self.entries:
+            if entry.name.startswith(base_pattern):
+                counter_type = entry.name.replace(base_pattern, "")  # rx, tx, drops, etc.
+                
+                if entry.type == VPPStatsType.COUNTER_VECTOR_SIMPLE:
+                    # Sum across all threads for this interface
+                    total = 0
+                    for thread_counters in entry.simple_counter_vec:
+                        if thread_counters:  # Check if thread has data
+                            total += sum(thread_counters)
+                    counters[f"{counter_type}_packets"] = total
+                    
+                elif entry.type == VPPStatsType.COUNTER_VECTOR_COMBINED:
+                    # Sum packets and bytes across all threads for this interface
+                    total_packets = 0
+                    total_bytes = 0
+                    for thread_counters in entry.combined_counter_vec:
+                        if thread_counters:  # Check if thread has data
+                            for counter_val in thread_counters:
+                                total_packets += counter_val.packets
+                                total_bytes += counter_val.bytes
+                    counters[f"{counter_type}_packets"] = total_packets
+                    counters[f"{counter_type}_bytes"] = total_bytes
+                    
+                elif entry.type == VPPStatsType.SCALAR:
+                    counters[counter_type] = entry.scalar_value
+                    
+        # Fallback: legacy aggregate vectors '/if/rx', '/if/tx', '/if/drops' + name vector '/if/names'
+        if counters:
+            return counters
+
+        # Find name vector entry (list of interface names in order of indices)
+        name_vec_entry = None
+        for entry in self.entries:
+            if entry.name in ("/if/names", "/if/name", "/if/interfaces") and entry.type == VPPStatsType.NAME_VECTOR:
+                name_vec_entry = entry
+                break
+        if not name_vec_entry:
+            return counters  # cannot map indices
+        try:
+            index = name_vec_entry.name_vector.index(interface_name)
+        except ValueError:
+            return counters  # interface name not present
+
+        # Helper to aggregate combined counters per interface index
+        def aggregate_combined(entry: 'VPPStatsEntry') -> Dict[str, int]:
+            packets_total = 0
+            bytes_total = 0
+            for thread_list in entry.combined_counter_vec:
+                if index < len(thread_list):
+                    cv = thread_list[index]
+                    packets_total += cv.packets
+                    bytes_total += cv.bytes
+            return {"packets": packets_total, "bytes": bytes_total}
+
+        # Helper for simple counters
+        def aggregate_simple(entry: 'VPPStatsEntry') -> int:
+            total = 0
+            for thread_list in entry.simple_counter_vec:
+                if index < len(thread_list):
+                    total += thread_list[index]
+            return total
+
+        # Scan legacy entries
+        legacy_map = {e.name: e for e in self.entries if e.name.startswith("/if/")}
+        rx_entry = legacy_map.get("/if/rx")
+        tx_entry = legacy_map.get("/if/tx")
+        drops_entry = legacy_map.get("/if/drops")
+
+        if rx_entry and rx_entry.type == VPPStatsType.COUNTER_VECTOR_COMBINED:
+            agg = aggregate_combined(rx_entry)
+            counters["rx_packets"] = agg["packets"]
+            counters["rx_bytes"] = agg["bytes"]
+        if tx_entry and tx_entry.type == VPPStatsType.COUNTER_VECTOR_COMBINED:
+            agg = aggregate_combined(tx_entry)
+            counters["tx_packets"] = agg["packets"]
+            counters["tx_bytes"] = agg["bytes"]
+        if drops_entry and drops_entry.type == VPPStatsType.COUNTER_VECTOR_SIMPLE:
+            counters["drops"] = aggregate_simple(drops_entry)
+
+        return counters
+        
+    def get_error_counters(self) -> Dict[str, List[int]]:
+        """Helper method to extract error counters"""
+        errors = {}
+        for entry in self.entries:
+            if entry.name.startswith('/err/') and entry.type == VPPStatsType.ERROR_INDEX:
+                error_name = entry.name.replace('/err/', '')
+                errors[error_name] = entry.error_vector
+        return errors
+
+    def summarize_interface(self, interface_name: str) -> Dict[str, int]:
+        """Return aggregated counters for a given interface.
+
+        Combines data from per-interface paths (/interfaces/<if>/rx, etc.) if present;
+        otherwise attempts legacy /if/* vector decoding using name vector mapping.
+        Keys returned (if available): rx_packets, rx_bytes, tx_packets, tx_bytes, drops.
+        """
+        result = self.get_interface_counters_by_name(interface_name)
+        if result:
+            return result
+        # Attempt legacy aggregation if not already populated
+        name_vec = None
+        for entry in self.entries:
+            if entry.name in ("/if/names", "/if/name", "/if/interfaces") and entry.type == VPPStatsType.NAME_VECTOR:
+                name_vec = entry.name_vector
+                break
+        if not name_vec:
+            return result
+        try:
+            idx = name_vec.index(interface_name)
+        except ValueError:
+            return result
+        # Locate legacy entries
+        rx_entry = next((e for e in self.entries if e.name == "/if/rx" and e.type == VPPStatsType.COUNTER_VECTOR_COMBINED), None)
+        tx_entry = next((e for e in self.entries if e.name == "/if/tx" and e.type == VPPStatsType.COUNTER_VECTOR_COMBINED), None)
+        drops_entry = next((e for e in self.entries if e.name == "/if/drops" and e.type == VPPStatsType.COUNTER_VECTOR_SIMPLE), None)
+        if rx_entry:
+            rx_packets = rx_bytes = 0
+            for thread_list in rx_entry.combined_counter_vec:
+                if idx < len(thread_list):
+                    rx_packets += thread_list[idx].packets
+                    rx_bytes += thread_list[idx].bytes
+            result["rx_packets"] = rx_packets
+            result["rx_bytes"] = rx_bytes
+        if tx_entry:
+            tx_packets = tx_bytes = 0
+            for thread_list in tx_entry.combined_counter_vec:
+                if idx < len(thread_list):
+                    tx_packets += thread_list[idx].packets
+                    tx_bytes += thread_list[idx].bytes
+            result["tx_packets"] = tx_packets
+            result["tx_bytes"] = tx_bytes
+        if drops_entry:
+            drops_total = 0
+            for thread_list in drops_entry.simple_counter_vec:
+                if idx < len(thread_list):
+                    drops_total += thread_list[idx]
+            result["drops"] = drops_total
+        return result
+
+
