@@ -1310,7 +1310,9 @@ class DNat44Handler(ConfigurationItemHandler):
         # ignoring twicenat flags as twice nat is not needed for failover case
         # isTwiceNat:     mapping.TwiceNat == nat.DNat44_StaticMapping_ENABLED,
         # isSelfTwiceNat: mapping.TwiceNat == nat.DNat44_StaticMapping_SELF,
-        flags = VppEnum.vl_api_nat_config_flags_t.NAT_IS_OUT2IN_ONLY
+        # NOTE: Removed NAT_IS_OUT2IN_ONLY flag due to VPP 25.06 compatibility issues
+        # with nat44_add_del_static_mapping_v2 API
+        flags = 0
         if (
             static_mapping.local_ips[0].local_port == 0
             and static_mapping.external_port == 0
