@@ -14,7 +14,8 @@ logger = configure_main_logger("papi-server", logging.INFO)
 
 from vpp_papi import VPPApiClient, VPPIOError
 
-from vpp_vrouter.server import __version__, pyro
+from vpp_vrouter.server import pyro
+from vpp_vrouter.server import __version__  # dynamically resolved from package / pyproject
 from vpp_vrouter.common.models import (
     SW_IF_INDEX,
     NO_INTERFACE_SW_INDEX,
@@ -38,6 +39,7 @@ from vpp_vrouter.common.models import (
     UpdateConfigurationItemsReply,
     RunningPacketCapture,
     IF_STATUS_API_FLAG_ADMIN_UP,
+    VPPStatsReply,
 )
 from vpp_vrouter.server.handlers import (
     InterfaceHandler,
@@ -241,6 +243,221 @@ class ExtendedVPPClient:
                 return record.configuration_item
         return None
 
+    def get_vpp_stats(self, query) -> 'VPPStatsReply':
+        """On-demand VPP statistics collection (transient query API only).
+
+        Accepts a VPPStatsQuery and returns a VPPStatsReply. Legacy configuration-item
+        based stats collection has been removed.
+        """
+        from datetime import datetime
+        from vpp_vrouter.common.models import (
+            VPPStatsReply,
+            VPPStatsEntry,
+            VPPStatsType,
+            VPPCounterValue,
+            VPPStatsQuery,
+        )
+
+        if not isinstance(query, VPPStatsQuery):
+            raise TypeError(
+                f"Unsupported stats query type: {type(query)}. Provide VPPStatsQuery"
+            )
+        try:
+
+            logger.info(
+                "Collecting VPP stats (transient) interfaces=%s patterns=%s include_errors=%s",
+                query.interface_names,
+                query.patterns,
+                query.include_error_counters,
+            )
+
+            # Build patterns/paths
+            stat_paths = set(query.patterns or [])
+
+            # Interface specific paths (modern)
+            for if_name in query.interface_names:
+                # Base path (may expand depending on VPP version)
+                stat_paths.add(f"/interfaces/{if_name}")
+                for leaf in ("rx", "tx", "drops"):
+                    stat_paths.add(f"/interfaces/{if_name}/{leaf}")
+
+            # Legacy interface paths '/if/<leaf>' aggregate - always include if user requested interfaces but no explicit pattern
+            if query.interface_names and not query.disable_legacy_interface_paths:
+                for leaf in ("rx", "tx", "drops"):
+                    stat_paths.add(f"/if/{leaf}")
+                # include names vector for index-to-name mapping fallback
+                stat_paths.add("/if/names")
+
+            # Error counters (avoid broad '/err' root; use common specific prefixes)
+            if query.include_error_counters:
+                stat_paths.update({
+                    "/err/ip4-input",
+                    "/err/ip6-input",
+                })
+
+            # If nothing specified default to interface aggregates
+            if not stat_paths:
+                stat_paths.update({"/if/rx", "/if/tx", "/if/drops"})
+
+            from vpp_papi.vpp_stats import VPPStats
+            import os
+
+            if not os.path.exists(query.stats_socket_path):
+                raise FileNotFoundError(f"Stats socket not found: {query.stats_socket_path}")
+
+            # Some versions of vpp_papi.vpp_stats.VPPStats expect the stats socket path
+            # as a positional first argument; older/newer variants may use different
+            # parameter names. Use a defensive instantiation strategy.
+            try:
+                stats_client = VPPStats(query.stats_socket_path)
+            except TypeError:
+                # Fallback: try without arguments (default path) and later verify path matches
+                stats_client = VPPStats()
+                if query.stats_socket_path != "/run/vpp/stats.sock":
+                    logger.warning(
+                        "Using default VPP stats socket; requested '%s' may be ignored by current vpp_papi version",
+                        query.stats_socket_path,
+                    )
+            # Collect stats per-path to avoid one failing path aborting everything
+            raw: dict = {}
+            path_failures: dict = {}
+            for p in sorted(stat_paths):
+                try:
+                    part = stats_client.dump([p])
+                    raw.update(part)
+                except Exception as pe:
+                    path_failures[p] = str(pe)
+            try:
+                stats_client.disconnect()
+            except Exception:
+                pass
+            timestamp = datetime.utcnow().isoformat()
+            entries: list[VPPStatsEntry] = []
+
+            def to_entry(name: str, value) -> VPPStatsEntry:
+                """Simplified conversion aligned with direct dump usage.
+
+                Rules:
+                  - list of (packets, bytes) tuples => combined counter vector (per-thread, single interface)
+                  - list of ints/floats => simple counter vector (per-thread, single interface) unless /err/ path
+                  - list of strings => name vector
+                  - dict (thread->list) retained (old heuristic) for completeness
+                  - scalar numeric => scalar
+                  - /err/ + list[int] => error vector
+                """
+                # Scalar
+                if isinstance(value, (int, float)):
+                    return VPPStatsEntry(name=name, type=VPPStatsType.SCALAR, scalar_value=float(value))
+
+                # List based structures
+                if isinstance(value, list):
+                    # Detect combined vector presented as list of StatsTuple/dict objects (one per interface per thread?)
+                    # Heuristic: entry like /interfaces/<if>/rx gives list length == threads, each element {packets, bytes}
+                    if value and all(
+                        (isinstance(x, (tuple, list)) and len(x) == 2 and all(isinstance(y, (int, float)) for y in x))
+                        or (isinstance(x, dict) and {'packets', 'bytes'} <= set(x.keys()))
+                        for x in value
+                    ):
+                        combined_vec = [[
+                            VPPCounterValue(
+                                packets=int(x[0] if not isinstance(x, dict) else x['packets']),
+                                bytes=int(x[1] if not isinstance(x, dict) else x['bytes'])
+                            )
+                        ] for x in value]
+                        return VPPStatsEntry(name=name, type=VPPStatsType.COUNTER_VECTOR_COMBINED, combined_counter_vec=combined_vec)
+
+                    # /if/rx style: list per thread where each element is a list of per-interface dicts {'packets','bytes'}
+                    if value and all(isinstance(thread_block, list) for thread_block in value):
+                        # Check if first thread block looks like list of dict packets/bytes
+                        first_block = value[0]
+                        if first_block and all(isinstance(d, dict) and {'packets','bytes'} <= set(d.keys()) for d in first_block):
+                            combined_vec: list[list[VPPCounterValue]] = []
+                            for thread_block in value:
+                                combined_vec.append([
+                                    VPPCounterValue(packets=int(d['packets']), bytes=int(d['bytes'])) for d in thread_block
+                                ])
+                            return VPPStatsEntry(name=name, type=VPPStatsType.COUNTER_VECTOR_COMBINED, combined_counter_vec=combined_vec)
+
+                    if value and all(isinstance(x, str) for x in value):
+                        return VPPStatsEntry(name=name, type=VPPStatsType.NAME_VECTOR, name_vector=value)
+                    if value and all(isinstance(x, (int, float)) for x in value):
+                        if name.startswith('/err/'):
+                            return VPPStatsEntry(name=name, type=VPPStatsType.ERROR_INDEX, error_vector=[int(x) for x in value])
+                        simple_vec = [[int(x)] for x in value]
+                        return VPPStatsEntry(name=name, type=VPPStatsType.COUNTER_VECTOR_SIMPLE, simple_counter_vec=simple_vec)
+
+                # Dict heuristic (legacy path)
+                if isinstance(value, dict):
+                    thread_values = list(value.values())
+                    if thread_values and all(isinstance(tv, list) for tv in thread_values):
+                        first_list = thread_values[0]
+                        if first_list and all(isinstance(x, (list, tuple)) and len(x) == 2 for x in first_list):
+                            combined_vec = []
+                            for thread_list in thread_values:
+                                combined_vec.append([
+                                    VPPCounterValue(packets=int(p), bytes=int(b)) for p, b in thread_list
+                                ])
+                            return VPPStatsEntry(name=name, type=VPPStatsType.COUNTER_VECTOR_COMBINED, combined_counter_vec=combined_vec)
+                        elif first_list and all(isinstance(x, (int, float)) for x in first_list):
+                            simple_vec = []
+                            for thread_list in thread_values:
+                                simple_vec.append([int(x) for x in thread_list])
+                            return VPPStatsEntry(name=name, type=VPPStatsType.COUNTER_VECTOR_SIMPLE, simple_counter_vec=simple_vec)
+
+                # Fallback to scalar zero
+                return VPPStatsEntry(name=name, type=VPPStatsType.SCALAR, scalar_value=0.0)
+
+            debug_lines = []
+            if getattr(query, 'debug', False):
+                debug_lines.append(f"Requested paths: {sorted(stat_paths)}")
+                if path_failures:
+                    debug_lines.append(f"Failed paths: {path_failures}")
+            for name, value in raw.items():
+                try:
+                    entry = to_entry(name, value)
+                    entries.append(entry)
+                    if getattr(query, 'debug', False):
+                        # Summarize shape
+                        if isinstance(value, list):
+                            sample = value[0] if value else None
+                            debug_lines.append(
+                                f"RAW {name}: list len={len(value)} sample_type={type(sample).__name__} sample={sample} mapped={entry.type.value}"
+                            )
+                        elif isinstance(value, dict):
+                            keys_preview = list(value.keys())[:3]
+                            debug_lines.append(
+                                f"RAW {name}: dict threads={len(value)} keys_preview={keys_preview} mapped={entry.type.value}"
+                            )
+                        else:
+                            debug_lines.append(
+                                f"RAW {name}: type={type(value).__name__} value_preview={str(value)[:60]} mapped={entry.type.value}"
+                            )
+                except Exception as conv_e:
+                    logger.warning("Failed to convert stat %s: %s", name, conv_e)
+                    if getattr(query, 'debug', False):
+                        debug_lines.append(f"ERROR converting {name}: {conv_e}")
+
+            partial_success = bool(entries)
+            reply = VPPStatsReply(
+                success=partial_success,
+                timestamp=timestamp,
+                entries=entries,
+                debug_info=debug_lines if getattr(query, 'debug', False) else [],
+            )
+            if not partial_success:
+                reply.error = "All requested paths failed" if path_failures else "No statistics collected"
+            logger.info("Collected %d VPP stats entries", len(entries))
+            return reply
+        except Exception as e:
+            error_msg = f"Failed to get VPP stats: {e}"
+            logger.error(error_msg, exc_info=True)
+            return VPPStatsReply(
+                success=False,
+                error=error_msg,
+                timestamp=datetime.now().isoformat(),
+                entries=[],
+            )
+
     def _get_handler(self, configuration_item):
         for handler in self.handlers:
             if handler.is_handling_configuration_item(configuration_item):
@@ -816,6 +1033,15 @@ def extended_papi_wrapper(vpp_client):
             finally:
                 self.lock.release()
 
+        def get_vpp_stats(self, stats_config) -> VPPStatsReply:
+            try:
+                self.lock.acquire(blocking=True)
+                return vpp_client.get_vpp_stats(stats_config)
+            except Exception:
+                logger.exception("Exception in get_vpp_stats")
+            finally:
+                self.lock.release()
+
     return Wrapper
 
 
